@@ -80,14 +80,14 @@ use MooseX::Types -declare => [
         ServiceVersion
         ServiceRootUri ServiceRoot NotServiceRoot SlashedPath
 
-        Query QueryType QueryName QueryHandler IllegalQueryName ListableQuery
+        Query QueryType QueryName QueryHandler IllegalQueryName Listable
 
         Template TemplateFactory TemplateHash
 
         SavedQuery SavedQueryFactory
 
         ListFactory List ListName CanTreatAsList
-        ListOfLists ListOfListableQueries
+        ListOfLists ListOfListables
 
         ListOperable ListOfListOperables 
 
@@ -284,8 +284,8 @@ subtype IllegalQueryName, as Str, where { /[^\w\.,\s-]/ };
 enum QueryType, [ 'template', 'saved-query', ];
 class_type QueryHandler, { class => 'Webservice::InterMine::Query::Handler', };
 class_type Query,        { class => 'Webservice::InterMine::Query::Core', };
-role_type ListableQuery, {role => 'Webservice::InterMine::Query::Roles::Listable'};
-subtype ListOfListableQueries, as ArrayRef[ListableQuery];
+role_type Listable, {role => 'Webservice::InterMine::Role::Listable'};
+subtype ListOfListables, as ArrayRef[Listable];
 coerce QueryName, from IllegalQueryName, 
     via { 
         s/[^a-zA-Z0-9_,. -]/_/g; 
@@ -312,7 +312,7 @@ subtype ListName, as Str;
 duck_type CanTreatAsList, ['to_list_name'];
 subtype ListOfLists, as ArrayRef[List];
 
-subtype ListOperable, as List|ListableQuery;
+subtype ListOperable, as List|Listable;
 subtype ListOfListOperables, as ArrayRef[ListOperable];
 
 coerce ListFactory, from HashRef, via {
@@ -320,7 +320,7 @@ coerce ListFactory, from HashRef, via {
     Webservice::InterMine::ListFactory->new( $_ );
 };
 
-coerce ListName, from ListableQuery, via {
+coerce ListName, from Listable, via {
     my $service = $_->service;
     my $list = eval {$service->new_list(content => $_)};
     if (my $e = $@) {
